var React = require('react');

var styles = {"code-item":"_1TXHq"};

var CodeItem = function CodeItem(props) {
  var itemClassName = props.itemClassName,
      value = props.value,
      _onChange = props.onChange,
      itemIndex = props.itemIndex,
      type = props.type,
      onClickHandler = props.onClickHandler,
      isFocused = props.isFocused,
      interactionCounter = props.interactionCounter,
      autoFocus = props.autoFocus,
      placeholder = props.placeholder,
      disabled = props.disabled;
  var inputRef = React.useRef(null);
  React.useEffect(function () {
    var inputEl = inputRef.current;

    if (interactionCounter === 0 && !autoFocus) {
      inputEl && inputEl.blur();
      return;
    }

    if (isFocused) {
      inputEl && inputEl.focus();
    } else {
      inputEl && inputEl.blur();
    }
  }, [isFocused, interactionCounter]);
  React.useEffect(function () {}, []);

  var handleFocus = function handleFocus(event) {
    return event.target.select();
  };

  return React.createElement(React.Fragment, null, React.createElement("input", {
    ref: inputRef,
    type: type,
    value: value || '',
    onChange: function onChange(e) {
      return _onChange(e, itemIndex);
    },
    className: "code-item " + styles['code-item'] + " " + itemClassName,
    onClick: function onClick() {
      return onClickHandler(itemIndex);
    },
    maxLength: 1,
    onFocus: handleFocus,
    placeholder: placeholder,
    disabled: disabled
  }));
};

var styles$1 = {"codes-container":"_1XM5Z"};

var CodeItemList = function CodeItemList(props) {
  var className = props.className,
      nItems = props.nItems,
      itemClassName = props.itemClassName,
      value = props.value,
      type = props.type,
      onChange = props.onChange,
      autoFocus = props.autoFocus,
      placeholder = props.placeholder,
      disabled = props.disabled;

  var _useState = React.useState(0),
      currentIndex = _useState[0],
      setCurrentIndex = _useState[1];

  var _useState2 = React.useState(0),
      interactionCounter = _useState2[0],
      setInteractionCounter = _useState2[1];

  var onChangeHandler = function onChangeHandler(e, _index) {
    var itemValue = e.target.value;
    var codeLength = value && value.length || 0;

    if (_index <= codeLength) {
      var str = value.split('');
      str[_index] = itemValue;
      str = str.join('');
      onChange(str);
      setCurrentIndex(currentIndex + 1);
    }
  };

  var onClickHandler = function onClickHandler(_index) {
    var codeLength = value && value.length || 0;

    if (_index > codeLength) {
      setCurrentIndex(codeLength);
    } else {
      setCurrentIndex(_index);
    }

    setInteractionCounter(interactionCounter + 1);
  };

  var placeholderFirstChar = React.useMemo(function () {
    if (placeholder && placeholder.length > 1) {
      return placeholder.charAt(0);
    }

    return placeholder;
  }, [placeholder]);

  var getElements = function getElements() {
    var retElements = [];

    if (!nItems) {
      return retElements;
    }

    for (var i = 0; i < nItems; i++) {
      var elValue = i > (value && value.length) ? '' : value[i];
      var el = React.createElement(CodeItem, {
        key: "item-" + i,
        value: elValue,
        onChange: onChangeHandler,
        onClickHandler: onClickHandler,
        itemClassName: itemClassName || '',
        itemIndex: i,
        type: type || 'text',
        currentIndex: currentIndex,
        setCurrentIndex: setCurrentIndex,
        isFocused: currentIndex === i,
        interactionCounter: interactionCounter,
        autoFocus: autoFocus,
        placeholder: placeholderFirstChar,
        disabled: disabled
      });
      retElements.push(el);
    }

    return retElements;
  };

  return React.createElement(React.Fragment, null, React.createElement("div", {
    className: "codes-container " + className + " " + styles$1['codes-container']
  }, getElements()));
};

var ReactInputCode = function ReactInputCode(props) {
  return React.createElement(CodeItemList, Object.assign({}, props));
};

module.exports = ReactInputCode;
//# sourceMappingURL=index.js.map
